Toxins
======
Toxins is a template tox-based project, providing some tools that can be used in other projects.

.. image:: https://travis-ci.org/simone-campagna/toxins.svg?branch=master
    :target: https://travis-ci.org/simone-campagna/toxins
    :alt: Build status

.. image:: https://readthedocs.org/projects/toxins/badge/?version=latest
    :target: http://toxins.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation Status
    
.. image:: https://coveralls.io/repos/github/simone-campagna/toxins.svg?branch=master
    :target: https://coveralls.io/github/simone-campagna/toxins?branch=master
    :alt: Coverage report

.. image:: https://badge.fury.io/py/toxins.svg
    :target: http://badge.fury.io/py/toxins
    :alt: PyPI version

.. image:: https://badge.fury.io/gh/simone-campagna%2Ftoxins.svg
    :target: http://badge.fury.io/gh/simone-campagna%2Ftoxins
    :alt: Github version

.. image:: https://img.shields.io/badge/license-Apache2.0-blue.svg
    :target: http://opensource.org/licenses/Apache2.0
    :alt: License

See the full documentation at http://toxins.readthedocs.org.
